==> player-3.0.11-sources.jar: com/transsion/player/orplayer/global/TnPlayerPool.kt <==
package com.transsion.player.orplayer.global

import android.content.Context
import com.transsion.player.exo.ORExoPlayer
import com.transsion.player.orplayer.ORPlayer

object TnPlayerPool {

    private val TAG = "TnPlayerPool"
//    private var aliPlayer: TnAliPlayer? = null
//    private var exoPlayer: ORExoPlayer? = null


    //    @Synchronized
    fun newAliPlayer(context: Context): TnAliPlayer {
//        val player = aliPlayer ?: TnAliPlayer.newInstance()
//        if (null != aliPlayer) {
//            Logger.d(TAG, "复用阿里播放器")
//            aliPlayer = null
//        }
        return TnAliPlayer.newInstance()
    }

    //    @Synchronized
    fun newExoPlayer(context: Context): ORExoPlayer {
//        val player = exoPlayer ?: ORExoPlayer(context.applicationContext)
//        if (null != exoPlayer) {
//            Logger.d(TAG, "复用exo播放器")
//            exoPlayer = null
//        }
        return ORExoPlayer(context.applicationContext)
    }

    //    @Synchronized
    fun needReleasePlayer(orPlayer: ORPlayer?): Boolean {
//        if (orPlayer is TnAliPlayer) {
//            return if (null == aliPlayer) {
//                aliPlayer = orPlayer
//                Logger.d(TAG, "阿里播放器进缓存池")
//                false
//            } else {
//                true
//            }
//        } else {
//            if (orPlayer is ORExoPlayer) {
//                return if (null == exoPlayer) {
//                    Logger.d(TAG, "exo播放器进缓存池")
//                    exoPlayer = orPlayer
//                    false
//                } else {
//                    true
//                }
//            }
//        }
        return true
    }
}

==> player-3.1.02-sources.jar: com/transsion/player/orplayer/global/TnPlayerPool.kt <==
package com.transsion.player.orplayer.global

import android.content.Context
import com.transsion.player.exo.ORExoPlayer
import com.transsion.player.ijk.IjkPlayer
import com.transsion.player.orplayer.ORPlayer

object TnPlayerPool {

    private val TAG = "TnPlayerPool"
//    private var aliPlayer: TnAliPlayer? = null
//    private var exoPlayer: ORExoPlayer? = null


    //    @Synchronized
    fun newAliPlayer(context: Context): TnAliPlayer {
//        val player = aliPlayer ?: TnAliPlayer.newInstance()
//        if (null != aliPlayer) {
//            Logger.d(TAG, "复用阿里播放器")
//            aliPlayer = null
//        }
        return TnAliPlayer.newInstance()
    }

    fun newIjkPlayer(context: Context): IjkPlayer {
        return IjkPlayer(context.applicationContext)
    }


    //    @Synchronized
    fun newExoPlayer(context: Context): ORExoPlayer {
//        val player = exoPlayer ?: ORExoPlayer(context.applicationContext)
//        if (null != exoPlayer) {
//            Logger.d(TAG, "复用exo播放器")
//            exoPlayer = null
//        }
        return ORExoPlayer(context.applicationContext)
    }

    //    @Synchronized
    fun needReleasePlayer(orPlayer: ORPlayer?): Boolean {
//        if (orPlayer is TnAliPlayer) {
//            return if (null == aliPlayer) {
//                aliPlayer = orPlayer
//                Logger.d(TAG, "阿里播放器进缓存池")
//                false
//            } else {
//                true
//            }
//        } else {
//            if (orPlayer is ORExoPlayer) {
//                return if (null == exoPlayer) {
//                    Logger.d(TAG, "exo播放器进缓存池")
//                    exoPlayer = orPlayer
//                    false
//                } else {
//                    true
//                }
//            }
//        }
        return true
    }
}
